@@ -206,8 +206,7 @@
                         .lambda = c(0, 10 ^ seq(-1, -4, length = len - 1))),
                       penalized = expand.grid(.lambda1 = 2^((1:len) -1),
                         .lambda2 = 2^((1:len) -1)),
-                      spls = expand.grid(.K = 1:len, .eta = seq(.1, .9, length = len)),
-                      splsda = expand.grid(.K = 1:len, .eta = seq(.1, .9, length = len), .kappa = .5),
+                      spls = expand.grid(.K = 1:len, .eta = seq(.1, .9, length = len), .kappa = .5),
                       sda = data.frame(.diagonal = FALSE),
                       mda = data.frame(.subclasses = (1:len) + 1),
                       pda = data.frame(.lambda = 1:len),
